@@ -31,11 +31,12 @@ HIVE_API_NODE = config['Global']['HIVE_API_NODE']
 HIVE = Hive(node=[HIVE_API_NODE], keys=[config['Global']['ACCOUNT_ACTIVE_KEY']])
 HIVE.chain_params['chain_id'] = 'beeab0de00000000000000000000000000000000000000000000000000000000'
 beem.instance.set_shared_blockchain_instance(HIVE)
+
+api = Api(url = "https://engine.rishipanthee.com", rpcurl = "https://engine.rishipanthee.com")
+
 ACCOUNT = Account(ACCOUNT_NAME)
 TOKEN_NAME = config['HiveEngine']['TOKEN_NAME']
 
-api = Api(url = "https://engine.rishipanthee.com")
-
 BOT_COMMAND_STR = config['Global']['BOT_COMMAND_STR']
 
 SQLITE_DATABASE_FILE = 'alivebot.db'
